using System;
using System.Diagnostics;
using Gtk;

public partial class MainWindow: Gtk.Window
{	
	public MainWindow (): base (Gtk.WindowType.Toplevel)
	{
		Build ();
	}
	
	protected void OnDeleteEvent (object sender, DeleteEventArgs a)
	{
		Application.Quit ();
		a.RetVal = true;
	}

	protected virtual void onActivate_QuitAction (object sender, System.EventArgs e)
	{
		Application.Quit ();
	}

	protected virtual void onActivate_AboutAction (object sender, System.EventArgs e)
	{
		AboutDialog a = new Gtk.AboutDialog();
		a.ProgramName = "PDFTK Simple GTK GUI";
        a.Version = "0.1";
        a.Comments = "A simple graphical user interface for the burst function provided by PDFTK";
        a.Copyright = "Copyright 2009 Benjamin Rousch";
        a.License = "GPL";
        a.Authors =  new string [] { "Benjamin Rousch <brousch@gmail.com>", "WMLUG" };
        a.Website = "http:/brousch.orthicomp.com/software/pdftkgui/";
        a.Run();
        a.Destroy();
	}

	protected virtual void onClick_btnBurstSelect (object sender, System.EventArgs e)
	{
		FileFilter ffPdf = new FileFilter();
        ffPdf.Name = "PDF Files (*.pdf)";
        ffPdf.AddPattern("*.pdf");
		
		FileChooserDialog fcdPdf = new FileChooserDialog(
                "Choose the file to open",
                this,
                FileChooserAction.Open,
                "Cancel",ResponseType.Cancel,
                "Open",ResponseType.Accept
        );
        fcdPdf.AddFilter(ffPdf);
        
        if (fcdPdf.Run() == (int)ResponseType.Accept) {
            entryBurst.Text = fcdPdf.Filename;
        }
        fcdPdf.Destroy(); 
	}

	protected virtual void onClick_btnBurstIt (object sender, System.EventArgs e)
	{
		Process proc = new Process();
		proc.StartInfo.FileName = "pdftk.exe";	// Windows PDFTK
		proc.StartInfo.Arguments = "\"" + entryBurst.Text + "\" burst";
		proc.StartInfo.UseShellExecute = false;
		proc.StartInfo.RedirectStandardOutput = false;
		try {
			proc.Start();
		}
		catch (Exception e1) {
			Console.WriteLine("Switching to Linux/OSX PDFTK.");
			try {
				proc.StartInfo.FileName = "pdftk";	// Linux, OSX PDFTK
				proc.Start();
			}
			catch (Exception e2) {
				Console.WriteLine("PDFTK not found.");
			}
		}
			
		proc.WaitForExit();
		
		MessageDialog dlgBurstDone = new MessageDialog(
			this,
		    DialogFlags.Modal,
		    MessageType.Info,
		    ButtonsType.Ok,
		    "Burst complete!"
		);
		dlgBurstDone.Run();
		dlgBurstDone.Destroy();

	}
	
}
